bayespy.inference.vmp.nodes.gaussian.WrapToGaussianWishart.add_plate_axis
=========================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: WrapToGaussianWishart.add_plate_axis